@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Controller/Settings.pm 1578 2008-05-10T01:30:21.225794Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Catalyst/Controller/Settings.pm 1644 2008-06-02T01:46:53.055259Z claco  $
 package Mango::Catalyst::Controller::Settings;
 use strict;
 use warnings;
@@ -33,19 +33,36 @@ sub profile : Local Template('settings/profile') {
     my $user    = $c->user;
     my $profile = $user->profile;
 
+    $form->unique(
+        'email',
+        sub {
+            my $existing =
+              $c->model('Profiles')
+              ->search( { email => $form->field('email') } )->first;
+
+            if ( $existing && $existing->id != $profile->id ) {
+                return;
+            } else {
+                return 1;
+            }
+        }
+    );
+
     $form->values(
         {
             username         => $user->username,
             password         => $user->password,
             confirm_password => $user->password,
             first_name       => $profile->first_name,
-            last_name        => $profile->last_name
+            last_name        => $profile->last_name,
+            email            => $profile->email
         }
     );
 
     if ( $self->submitted && $self->validate->success ) {
         $profile->first_name( $form->field('first_name') );
         $profile->last_name( $form->field('last_name') );
+        $profile->email( $form->field('email') );
         $profile->update;
 
         $c->user->refresh;
