@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/lib/Mango/Provider/DBIC.pm 1578 2008-05-10T01:30:21.225794Z claco  $
+# $Id: /local/CPAN/Mango/lib/Mango/Provider/DBIC.pm 1644 2008-06-02T01:46:53.055259Z claco  $
 package Mango::Provider::DBIC;
 use strict;
 use warnings;
@@ -71,6 +71,14 @@ sub schema {
     my ( $self, $schema ) = @_;
 
     if ($schema) {
+        $schema->exception_action(
+            sub {
+                Mango::Exception->throw(@_);
+
+                return;
+            }
+        );
+
         $self->_schema($schema);
     } elsif ( !$self->_schema ) {
         if ( !$self->schema_class ) {
@@ -79,6 +87,14 @@ sub schema {
         $self->_schema(
             $self->schema_class->connect( @{ $self->connection_info || [] } )
         );
+
+        $self->_schema->exception_action(
+            sub {
+                Mango::Exception->throw(@_);
+
+                return;
+            }
+        );
     }
 
     return $self->_schema;
