@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Mango/t/lib/Mango/Test/Catalyst/Request.pm 1578 2008-05-10T01:30:21.225794Z claco  $
+# $Id: /local/CPAN/Mango/t/lib/Mango/Test/Catalyst/Request.pm 1644 2008-06-02T01:46:53.055259Z claco  $
 package Mango::Test::Catalyst::Request;
 use strict;
 use warnings;
@@ -19,7 +19,10 @@ sub header {
 };
 
 sub param {
-    return shift->{$_[0]};
+    my ($self, $name) = @_;
+
+    return $self->{$name} if defined $name;
+    return keys %{$self};
 };
 
 sub method {
